Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(878)

Unified Diff: media/base/android/media_drm_bridge_client.h

Issue 2756333002: Rename MediaClientAndroid to MediaDrmBridgeClient (Closed)
Patch Set: Fix .h guards Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/base/android/media_drm_bridge.cc ('k') | media/base/android/media_drm_bridge_client.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/base/android/media_drm_bridge_client.h
diff --git a/media/base/android/media_client_android.h b/media/base/android/media_drm_bridge_client.h
similarity index 61%
rename from media/base/android/media_client_android.h
rename to media/base/android/media_drm_bridge_client.h
index 909022bef0a6d1755e67ac76195f815a27fca007..7237f682acea37766a531f29bcefae3ca02a9cab 100644
--- a/media/base/android/media_client_android.h
+++ b/media/base/android/media_drm_bridge_client.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef MEDIA_BASE_ANDROID_MEDIA_CLIENT_ANDROID_H_
-#define MEDIA_BASE_ANDROID_MEDIA_CLIENT_ANDROID_H_
+#ifndef MEDIA_BASE_ANDROID_MEDIA_DRM_BRIDGE_CLIENT_H_
+#define MEDIA_BASE_ANDROID_MEDIA_DRM_BRIDGE_CLIENT_H_
#include <stdint.h>
@@ -17,44 +17,44 @@
namespace media {
-class MediaClientAndroid;
+class MediaDrmBridgeClient;
class MediaDrmBridgeDelegate;
-// Setter for MediaClientAndroid. This should be called in all processes where
-// we want to run media Android code. Also it should be called before any media
-// playback could occur.
-MEDIA_EXPORT void SetMediaClientAndroid(MediaClientAndroid* media_client);
+// Setter for MediaDrmBridgeClient. This should be called in all processes
+// where we want to run media Android code. Also it should be called before any
+// media playback could occur.
+MEDIA_EXPORT void SetMediaDrmBridgeClient(MediaDrmBridgeClient* media_client);
#if defined(MEDIA_IMPLEMENTATION)
// Getter for the client. Returns nullptr if no customized client is needed.
-MediaClientAndroid* GetMediaClientAndroid();
+MediaDrmBridgeClient* GetMediaDrmBridgeClient();
#endif
using UUID = std::vector<uint8_t>;
// A client interface for embedders (e.g. content/browser or content/gpu) to
// provide customized additions to Android's media handling.
-class MEDIA_EXPORT MediaClientAndroid {
+class MEDIA_EXPORT MediaDrmBridgeClient {
public:
typedef base::hash_map<std::string, UUID> KeySystemUuidMap;
- MediaClientAndroid();
- virtual ~MediaClientAndroid();
+ MediaDrmBridgeClient();
+ virtual ~MediaDrmBridgeClient();
// Adds extra mappings from key-system name to Android UUID into |map|.
virtual void AddKeySystemUUIDMappings(KeySystemUuidMap* map);
// Returns a MediaDrmBridgeDelegate that corresponds to |scheme_uuid|.
// MediaClientAndroid retains ownership.
virtual media::MediaDrmBridgeDelegate* GetMediaDrmBridgeDelegate(
const UUID& scheme_uuid);
private:
friend class KeySystemManager;
- DISALLOW_COPY_AND_ASSIGN(MediaClientAndroid);
+ DISALLOW_COPY_AND_ASSIGN(MediaDrmBridgeClient);
};
} // namespace media
-#endif // MEDIA_BASE_ANDROID_MEDIA_CLIENT_ANDROID_H_
+#endif // MEDIA_BASE_ANDROID_MEDIA_DRM_BRIDGE_CLIENT_H_
« no previous file with comments | « media/base/android/media_drm_bridge.cc ('k') | media/base/android/media_drm_bridge_client.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -17,44 +17,44 @@
virtual void AddKeySystemUUIDMappings(KeySystemUuidMap* map);
// Returns a MediaDrmBridgeDelegate that corresponds to |scheme_uuid|.
- // MediaClientAndroid retains ownership.
+ // MediaDrmBridgeClient retains ownership.
virtual media::MediaDrmBridgeDelegate* GetMediaDrmBridgeDelegate(
const UUID& scheme_uuid);
This is Rietveld 408576698